@@ -712,7 +712,7 @@ char *amap_printable_banner_string(char *string, int slen, char *banner, int ble
   if (slen < 1 || string == NULL || banner == NULL || blen < 1)
     return "";
   
-  while (i < blen - 1 && j < slen) {
+  while (i < blen - 2 && j < slen) {
     if (string[j] != ':' && (isprint(string[j]) || isspace(string[j]))) {
       if ((isspace(string[j]) && string[j] != ' ') || string[j] == '\\') {
         banner[i] = '\\';
@@ -991,10 +991,10 @@ void amap_read_responses(amap_struct_coms *coms, amap_struct_responses *response
           }
           // if !found then now response matched the received data, report this
           if (found < 1 && (opt->dump_all || (coms[i].port->unknown_response == NULL && coms[i].port->ids == NULL))) {
-            if (opt->verbose)
+            //if (opt->verbose)
               snprintf(info, sizeof(info), "(by trigger %s) ", coms[i].trigger->id);
-            else
-              info[0] = 0;
+            //else
+            //  info[0] = 0;
             if (opt->logfile != NULL && !opt->machine_readable) {
               fprintf(opt->logfile, "Unrecognized response from %s:%d/%s%s%sreceived.\n", coms[i].target->target, coms[i].port->port, coms[i].port->ip_prot == AMAP_PROTO_TCP ? "tcp" : "udp", coms[i].ssl_enabled ? " over SSL " : " ", info);
               if (opt->dump_unidentified) {
@@ -1122,7 +1122,7 @@ void amap_check_connects(amap_struct_coms *coms, amap_struct_scaninfo *scaninfo,
   if (opt->verbose > 3)
     printf("DEBUG: entering amap_check_connects\n");
   
-  // #1 : check for finnished connects
+  // #1 : check for finished connects
 /**/
 // variant 1
   FD_ZERO(&rfd);
@@ -2081,9 +2081,9 @@ int main(int argc, char *argv[]) {
   if (opt.logfile != NULL) {
     if (opt.machine_readable)
       fprintf(opt.logfile, "# ");
-    fprintf(opt.logfile, "%s %s finnished at %s\n", AMAP_PROGRAM, AMAP_VERSION, today);
+    fprintf(opt.logfile, "%s %s finished at %s\n", AMAP_PROGRAM, AMAP_VERSION, today);
   }
-  printf("\n%s %s finnished at %s\n", AMAP_PROGRAM, AMAP_VERSION, today);
+  printf("\n%s %s finished at %s\n", AMAP_PROGRAM, AMAP_VERSION, today);
 
   return 0;
 }
